===
NVM
===

.. image:: https://img.shields.io/pypi/v/nvm?version=latest
   :target: https://pypi.python.org/pypi/nvm
   :alt: PyPI Version

.. image:: https://img.shields.io/pypi/l/nvm?color=blueviolet
   :target: https://github.com/cogsys-io/nvm/blob/master/LICENSE
   :alt: License

.. image:: https://img.shields.io/github/actions/workflow/status/cogsys-io/nvm/build-main.yml
   :alt: GitHub Workflow (Build Main) Status
   :target: https://github.com/cogsys-io/nvm

.. image:: https://readthedocs.org/projects/nvm/badge/?version=latest
   :target: https://nvm.readthedocs.io/en/latest
   :alt: Documentation Status

Plenty little helpers.

* PyPi: https://pypi.org/project/nvm/
* GitHub: https://github.com/cogsys-io/nvm
* Documentation: https://nvm.readthedocs.io
* Developers: https://cogsys.io
* Free software: GNU General Public License v3

Features
--------

* Plenty little helpers.

Credits
-------

This package was created with Cookiecutter_ and the `cogsys-io/cogsys-io-cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/cookiecutter/cookiecutter
.. _`cogsys-io/cogsys-io-cookiecutter-pypackage`: https://github.com/cogsys-io/cogsys-io-cookiecutter-pypackage
